
Contributing to fortls
======================

There are a few ways you can support the ``fortls`` project.

Financial Support
------------------

You can fiscally support Fortran-lang by donating to the project, see
`Fortran-lang - NumFOCUS`_.

.. _Fortran-lang - NumFOCUS: https://numfocus.org/donate-for-fortran-lang


.. .. grid:: 2
..     :gutter: 0
..     :class-container: sd-text-center sd-pt-4
..     :class-row: sd-align-minor-center

..     .. grid-item::
..         .. button-link:: https://github.com/sponsors/gnikit
..             :ref-type: ref
..             :outline:
..             :color: danger
..             :class: sd-px-2 sd-fs-4

..             Become a **Sponsor**
..             :octicon:`mark-github;2em;sd-text-black`
..             :octicon:`heart-fill;2em;sd-text-danger`

..     .. grid-item::
..         .. button-link:: https://www.paypal.com/paypalme/inikit
..             :ref-type: ref
..             :color: primary
..             :class: sd-px-2 sd-fs-5

..             Make a **Donation**
..             :fa:`fa-paypal`


Contributing Code
-----------------

.. include:: ./../CONTRIBUTING.md
    :parser: myst_parser.sphinx_
    :start-line: 2
